@@ -23,5 +23,20 @@ RESPONSES = ResponseSet(
             "access_token": _token,
             "scope": _scope,
         },
-    )
+    ),
+    openid=RegisteredResponse(
+        service="auth",
+        path="/v2/oauth2/token",
+        method="POST",
+        status=200,
+        json={
+            "access_token": "auth_access_token",
+            "scope": "openid",
+            "expires_in": 172800,
+            "token_type": "Bearer",
+            "resource_server": "auth.globus.org",
+            "id_token": "openid_token",
+            "other_tokens": [],
+        },
+    ),
 )
