@@ -7,10 +7,6 @@ GroupsScopes = ScopeBuilder(
         "view_my_groups_and_memberships",
     ],
 )
-"""Groups scopes.
-
-.. listknownscopes:: globus_sdk.scopes.GroupsScopes
-"""
 
 
 NexusScopes = ScopeBuilder(
@@ -19,7 +15,3 @@ NexusScopes = ScopeBuilder(
         "groups",
     ],
 )
-"""Nexus scopes (internal use only).
-
-.. listknownscopes:: globus_sdk.scopes.NexusScopes
-"""
