@@ -2,7 +2,13 @@ from .clients import GetClientsResponse
 from .consents import GetConsentsResponse
 from .credentials import GetClientCredentialsResponse
 from .identities import GetIdentitiesResponse, GetIdentityProvidersResponse
-from .oauth import OAuthDependentTokenResponse, OAuthTokenResponse
+from .oauth import (
+    OAuthAuthorizationCodeResponse,
+    OAuthClientCredentialsResponse,
+    OAuthDependentTokenResponse,
+    OAuthRefreshTokenResponse,
+    OAuthTokenResponse,
+)
 from .policies import GetPoliciesResponse
 from .projects import GetProjectsResponse
 from .scopes import GetScopesResponse
@@ -16,6 +22,9 @@ __all__ = (
     "GetPoliciesResponse",
     "GetProjectsResponse",
     "GetScopesResponse",
-    "OAuthTokenResponse",
+    "OAuthAuthorizationCodeResponse",
+    "OAuthClientCredentialsResponse",
     "OAuthDependentTokenResponse",
+    "OAuthRefreshTokenResponse",
+    "OAuthTokenResponse",
 )
